"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var utils_1 = require("./utils");
function control_data(st) {
    /**
     * Update status
     * @param key keyname state
     * @param value value state
     * @param pending Activates pending status update mode.
     * To confirm this update it will require the confirm method, otherwise use the cancel method.
     * A pending status is not detected as a change
     */
    function set(key, value, pending) {
        if (!st.has(key))
            return false;
        if (pending) {
            st.stpd.set(key, value);
        }
        else {
            st.stpd.delete(key);
            st.set(key, value);
        }
        return true;
    }
    function confirm(key) {
        if (key === undefined) {
            var size = st.stpd.size;
            st.stpd.forEach(function (val_pd, key_pd) {
                st.set(key_pd, val_pd);
                st.stpd.delete(key_pd);
            });
            st.stpd.clear();
            return size !== 0;
        }
        var val_pd = st.stpd.get(key);
        if (val_pd !== undefined && st.stpd.has(key)) {
            st.set(key, val_pd);
            st.stpd.delete(key);
            return true;
        }
        return false;
    }
    function cancel(key) {
        if (key === undefined) {
            var size = st.stpd.size;
            st.stpd.clear();
            return size !== 0;
        }
        return st.stpd.delete(key);
    }
    function frozen(key) {
        var value = st.get(key);
        return value !== undefined ? value : null;
    }
    function init(store) {
        if (store) {
            var list = store();
            for (var key in list) {
                var val = list[key];
                if (utils_1.isSttore(val)) {
                    val.cancel();
                }
                st.backup.set(key, val);
            }
            st.initial = JSON.stringify(list);
        }
        else {
            var init_list = JSON.parse(st.initial);
            for (var key in st.list()) {
                var val = st.list()[key];
                if (utils_1.isSttore(val)) {
                    val.init();
                }
                else {
                    st.set(key, init_list[key]);
                    st.backup.set(key, init_list[key]);
                }
            }
        }
        st.stpd.clear();
        st.sthp.forEach(function (value, key) {
            st.sthp.set(key, '');
        });
    }
    return { set: set, confirm: confirm, cancel: cancel, init: init, frozen: frozen };
}
exports.default = control_data;
